@@ -1,8 +1,9 @@
+import asyncio
 import logging
-import threading
 import slixmpp
 import slixmpp.xmlstream
-from typing import Any
+from typing import Any, Optional
+from slixmpp.xmlstream import StanzaBase
 
 from pyobs.comm.slixmpp.xep_0009.rpc import XEP_0009
 from pyobs.comm.slixmpp.xep_0009_timeout import XEP_0009_timeout
@@ -27,10 +28,11 @@ class XmppClient(slixmpp.ClientXMPP):  # type: ignore
         slixmpp.ClientXMPP.__init__(self, jid, password)
 
         # stuff
-        self._connect_event = threading.Event()
+        self._connect_event = asyncio.Event()
         self._logs_node = "logs"
-        self._auth_event = threading.Event()
+        self._auth_event = asyncio.Event()
         self._auth_success = False
+        self._jid_conflict = False
 
         # auto-accept invitations
         self.auto_authorize = True
@@ -52,8 +54,16 @@ class XmppClient(slixmpp.ClientXMPP):  # type: ignore
         self.add_event_handler("session_start", self.session_start)
         self.add_event_handler("auth_success", lambda ev: self._auth(True))
         self.add_event_handler("failed_auth", lambda ev: self._auth(False))
+        self.add_filter("in", self._filter_messages)
 
-    def wait_connect(self) -> bool:
+    def _filter_messages(self, stanza: StanzaBase) -> Optional[StanzaBase]:
+        # if a user with same JID is already connected, we get a conflict
+        if '<conflict xmlns="urn:ietf:params:xml:ns:xmpp-stanzas" />' in str(stanza):
+            self._jid_conflict = True
+            return None
+        return stanza
+
+    async def wait_connect(self) -> bool:
         """Wait for client to connect.
 
         Returns:
@@ -61,13 +71,17 @@ class XmppClient(slixmpp.ClientXMPP):  # type: ignore
         """
 
         # wait for auth and check
-        self._auth_event.wait()
+        await self._auth_event.wait()
         if not self._auth_success:
             log.error("Invalid credentials for connecting to XMPP server.")
             return False
 
         # wait for final connect
-        self._connect_event.wait()
+        while not self._connect_event.is_set():
+            if self._jid_conflict:
+                log.error("Another user is already connected with the same JID.")
+                return False
+            await asyncio.sleep(0.1)
 
         # connected
         return True
@@ -88,10 +102,10 @@ class XmppClient(slixmpp.ClientXMPP):  # type: ignore
         self._connect_event.set()
 
     def _auth(self, success: bool) -> None:
-        """Called after authentification.
+        """Called after authentication.
 
         Args:
-            success: Whether or not the authentification was successful.
+            success: Whether or not the authentication was successful.
         """
         # store and fire
         self._auth_success = success
